import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
        long_description = fh.read()

setuptools.setup(
    name="ShiningArmor", 
    version="0.0.7",
    author="Phani Adabala",
    author_email="adabala.phani@gmail.com",
    description="A collection of python functions for BOTs",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/adabalap/ShiningArmor",
    project_urls={
        "Bug Tracker": "https://github.com/adabalap/ShiningArmor/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
    install_requires=[
        "certifi==2021.5.30",
        "charset-normalizer==2.0.4",
        "EasyProcess==0.3",
        "idna==3.2",
        "oauthlib==3.1.1",
        "PySocks==1.7.1",
        "PyVirtualDisplay==2.2",
        "requests==2.26.0",
        "requests-oauthlib==1.3.0",
        "selenium==3.141.0",
        "six==1.16.0",
        "tweepy==3.10.0",
        "urllib3==1.26.6"
    ]
)



from pyvirtualdisplay import Display

from selenium import webdriver
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.keys import Keys

from time import time, ctime, sleep


def wa_init():
    # Initialize WhatsApp
    rc = 0
    t = time()

    try:
        options = Options()
        options.add_argument("--no-sandbox")
        options.add_argument("user-data-dir=" + "cookies")

        display = Display(visible=0)
        display.start()

        driver = webdriver.Chrome(options=options)
        driver.maximize_window()
        driver.get('https://web.whatsapp.com')

        sleep(20)
    except Exception as err:
        print(f'{ctime(t)} | Exception occurred in wa_init() function \n {err}')
        rc = 1

    return rc, driver, display


def wa_close(driver, display):
    # close connection to WhatsApp
    driver.quit()
    display.stop()


def wa_locate_contact(driver, wa_contact):
    # Find the WhatsApp contact
    rc = 0
    t = time()

    try:
        driver.find_element_by_xpath('//*[@title = "{}"]'.format(wa_contact)).click()
        sleep(10)
    except Exception as err:
        print(f'{ctime(t)} | Exception occurred in wa_contact() function \n {err}')
        rc = 1

    return rc


def wa_send_message(driver, display, wa_message_list):
    rc = 0
    t = time()

    try:
        wa_msg = driver.find_element_by_xpath('//*[@id="main"]/footer/div[1]/div[2]/div/div[1]')

        # message in one-block
        for i in wa_message_list:
            wa_msg.send_keys(i + Keys.SHIFT + Keys.RETURN)

        wa_msg.send_keys(Keys.ENTER)
        sleep(15)

        print(f'{ctime(t)} | WhatsApp message successfully sent!')

        wa_close(driver, display)

    except Exception as err:
        print(f'{ctime(t)} | Exception occurred in wa_contact() function \n {err}')
        rc = 1

    return rc